@@ -1021,10 +1021,10 @@ def pcd(func,dnamsel,datin,datout,appenddim = False, maxmembytes = 10000000, for
             # we are in the special case of an extra dimension to be prepended to the input
             if (list() in shapein) and (forcearray):
                 for ivsdin,evsdin in enumerate(vsdin):
-                    ahunkin.shape = [1]+shapein[ivsdin]
+                    ahunkin[ivsdin].shape = [1]+shapein[ivsdin]
             else:
                 for ivsdin,evsdin in enumerate(vsdin):
-                    ahunkin.shape = shapein[ivsdin]
+                    ahunkin[ivsdin].shape = shapein[ivsdin]
                     # apply the function
     
             ahunkout =  func(*ahunkin)
